{% extends '__base__.html' %}
{% load i18n %}

{% block content %}

  <h1 class="center-align">{% trans "Select the test" %}</h1>

  <div class="row">

    <div class="col s12 m6">
      <div class="card">
        <div class="card-content">
          <span class="card-title">Lactate threshold test</span>
          <p></p>
        </div>
        <div class="card-action">
          <div class="right-align"><a href="{% url 'lactate_analyses' %}">{% trans "Next" %}</a></div>
        </div>
      </div>
    </div>

    <div class="col s12 m6">
      <div class="card">
        <div class="card-content">
          <span class="card-title">Conconi test</span>
          <p></p>
        </div>
        <div class="card-action">
          <div class="right-align"><a href="{% url 'conconi_test' %}">{% trans "Next" %}</a></div>
        </div>
      </div>
    </div>


  </div>

{% endblock content %}
