{% load i18n %}

<li><a href="{% url 'index' %}">{% trans "Home" %}</a></li>
{% if user.id %}
  <li><a href="{% url 'logout' %}">{% trans "Log out" %}</a></li>
{% else %}
  <li><a href="{% url 'login' %}">{% trans "Log in" %}</a></li>
{% endif %}
