<nav role="navigation">
  <div class="nav-wrapper container">
    <a href="#" class="brand-logo">Pulse performance</a>
    <ul id="nav-mobile" class="right hide-on-med-and-down">
      {% include '__menu__.html' %}
    </ul>
  </div>
</nav>
